@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * $Id: TestSuite.java,v 1.24 2000/11/12 14:59:34 metlov Exp $
+ * $Id: TestSuite.java,v 1.26 2001/01/22 15:58:20 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -24,7 +24,7 @@ public class TestSuite {
   
   static int successes=0;
   static int failures=0;
-  static boolean abort_at_error=false;// Set if You want to abort at a failing
+  static boolean abort_at_error=true;// Set if You want to abort at a failing
   // test, works only for testExpression().
   
   public static void main(String[] args) {
@@ -309,11 +309,12 @@ public class TestSuite {
 
     o.println(); o.println("----- DOT OPERATOR ------");
     // Construct a new library
-    Class[] dotLib=new Class[3];
+    Class[] dotLib=new Class[4];
     try {
       dotLib[0]=Class.forName("java.lang.String");
       dotLib[1]=Class.forName("java.lang.Double");
       dotLib[2]=Class.forName("gnu.jel.reflect.Double");
+      dotLib[3]=DoubleObject.class;
     } catch(ClassNotFoundException e) {
       System.out.println(e);
       System.exit(1);
@@ -332,7 +333,7 @@ public class TestSuite {
     testError("2.0.doubleValue()",null,lib,5,o);
     
     testExpression("intObj+1", new Integer(556), null, rtp, lib,o);
-    testExpression("intObj", new Integer(555), null, rtp, lib,o);
+    testExpression("(int)intObj", new Integer(555), null, rtp, lib,o);
     testExpression("arr[intObj-554]", new Double(5.0), null, rtp, lib,o);
     testExpression("arr[max(intObj-554,0)]", new Double(5.0), null, rtp, lib,o);
     testExpression("arr[max(intObj,0)-554]", new Double(5.0), null, rtp, lib,o);
@@ -358,12 +359,13 @@ public class TestSuite {
     testExpression("p1.s1", "p1s1value", null, rtp, lib,o);
     testExpression("p1.s2", "p1s2value", null, rtp, lib,o);
     testExpression("p1.s2.ss1","p1s2ss1value", null, rtp, lib,o);
+    testExpression("p1.d1.aMethod()", new Integer(1), null, rtp, lib,o);
     testExpression("p1.s2.length()", new Integer(9), null, rtp, lib,o);
     testExpression("p1+(p1.d1+p1.s2.length()+1)", "p1value11.0", null, rtp, lib,o);
     testExpression("round(p1.d1)", new Long(1), null, rtp, lib,o);
     testExpression("p1.d1>0", new Boolean(true), null, rtp, lib,o);
     testExpression("p1.d1>0?p1.d1:3.0", new Double(1.0), null, rtp, lib,o);
-    testExpression("p1.b1t", new Boolean(true), null, rtp, lib,o);
+    testExpression("p1.b1t", new Boolean(true), Boolean.TYPE, rtp, lib,o);
     testExpression("(boolean)p1.b1t", new Boolean(true), null, rtp, lib,o);
     testExpression("p1.b1t?1:0", new Byte((byte)1), null, rtp, lib,o);
 
@@ -427,6 +429,50 @@ public class TestSuite {
       };
     };
 
+    {
+      o.println();
+      o.println("Check transmittance of unwrappable objects");
+      String[] typeNames={"Boolean","Byte","Character","Short","Integer",
+                          "Long","Float","Double"};
+      for(int k=0;k<8;k++) {
+        String fname="val"+typeNames[k]+"JELObj";
+        Object res=null;
+        try {
+          res=VariableProvider.class.getField(fname).get(vp);
+        } catch(Exception e) {
+          System.out.println(e);
+          System.exit(1);
+          };
+        testExpression(fname,res,null,rtp,lib,o);
+      };
+    };
+    
+    o.println(); o.println("----- CONCATENATION OF STRINGS ------");
+
+    testExpression("valString",new StringObject("strObj"),
+                   null, rtp, lib, o);
+
+    testExpression("valString+\"_ttt\"","strObj_ttt", 
+                   null, rtp, lib, o);
+
+    testExpression("\"ttt_\"+valString+\"_ttt\"","ttt_strObj_ttt", 
+                   null, rtp, lib, o);
+
+    testExpression("append_ttt(\"strObj\")+\"_ttt\"","strObj_ttt_ttt",
+                   null, rtp, lib, o);
+
+    testExpression("append_ttt(valString)+\"_ttt\"","strObj_ttt_ttt",
+                   null, rtp, lib, o);
+
+    o.println(); o.println("----- OVERLOADING OF UNWRAPPABLE TYPES ------");
+
+    testExpression("methodOnInt(valInteger)",new Integer(1), 
+                   null, rtp, lib, o);
+
+    testExpression("methodOnInt(valIntegerJELObj)",new Integer(2), 
+                   null, rtp, lib, o);
+
+
     for(int k=0;k<2;k++) {
       o.println(); 
       o.println("----- THOROUGNLY TEST UNARY OPERATIONS  ------");
