@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
- * $Id: OPbinary.java,v 1.4 2000/09/09 19:51:48 metlov Exp $
+ * $Id: OPbinary.java,v 1.5 2001/01/21 22:38:46 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -93,8 +93,8 @@ public class OPbinary extends OPfunction {
     OP p2CvtPlaceholder=(OP)paramOPs.pop();
     OP p1CvtPlaceholder=(OP)paramOPs.pop();
 
-    // separate out the string concatenation
-    if (((op1ID==10) || (op1ID==11)) && (code==0))
+    // separate out string concatenation
+    if (((op1ID==10) || (TypesStack.unwrapType[op1ID]==11)) && (code==0))
       opcode=20;
 
     this.code=opcode;
@@ -147,9 +147,11 @@ public class OPbinary extends OPfunction {
       opsIDX=TypesStack.baseType[resID];
       break;
     case 4: // string concatenation promotion
-      if ((op1ID!=10) && (op1ID!=11)) //STRCAT defined on TSBs or Strings 
-        throw new CompilationException(-1,17,null);
-      opsIDX=TypesStack.baseType[op2ID];
+      if (op2ID==11)
+        opsIDX=11;  // Strings handled in a special way for performance
+      else 
+        opsIDX=TypesStack.baseType[op2ID];
+
       op1cvtID=10; // TSB
       resID=10;  // TSB
       break;
