@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
- * $Id: OPunary.java,v 1.6 2000/11/12 14:59:34 metlov Exp $
+ * $Id: OPunary.java,v 1.8 2001/01/22 15:58:20 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -82,27 +82,30 @@ public class OPunary extends OPfunction {
     this.code=code;
     
     int opID=typesStk.peekID();
-    int unwrpID=TypesStack.unwrapType[opID];
     Class opType=typesStk.pop();
 
-    // unwrap object
-    if (unwrpID!=opID) {
-      uwrpCode=((opID-12+11)<<8)+0x00FE;
-      uwrpsTo=unwrpID;
-    };
+    if (code==3) { // return
+      // everything can be returned no checks/unwraps needed
+      resID=TypesStack.baseType[opID];
+      implCode=una[code][resID];
+    } else {
+      
+      // unwrap object if needed
+      int unwrpID=TypesStack.unwrapType[opID];      
+      if (unwrpID!=opID) {
+        uwrpCode=((opID-12+11)<<8)+0x00FE;
+        uwrpsTo=unwrpID;
+      };
 
-    if ((implCode=una[code][unwrpID])==0xFF) {
-      // operation is not defined on types
-      Object[] paramsExc={opNames[code],opType};
-      throw new CompilationException(-1,28,paramsExc);
-    };
-
-    // ordinary ops do unary promotion
-    // return stores the type, destroys the value
-    if (code!=3) {       
+      if ((implCode=una[code][unwrpID])==0xFF) {
+        // operation is not defined on types
+        Object[] paramsExc={opNames[code],opType};
+        throw new CompilationException(-1,28,paramsExc);
+      };
+      
       resID=unary_prmtns[unwrpID];
       typesStk.pushID(resID,null);      
-    } else resID=TypesStack.baseType[unwrpID]; 
+    };
   };
 
   /**
@@ -128,10 +131,14 @@ public class OPunary extends OPfunction {
 
     // The next if is needed because base type correctly says TSBs and Strings
     // are references, but we need to treat them separately here.
-    if ((resID==10) || (resID==11))
+    if (resID==10) {
       code=4+resID;
-    else {
-      code=4+TypesStack.baseType[resID];
+      if (currID==28) unwrappedCurrID=8;
+    } else {
+      if (resID==11)
+        code=4+resID;
+      else
+        code=4+TypesStack.baseType[resID];
       if (unwrappedCurrID!=currID) {
         uwrpCode=((currID-12+11)<<8)+0x00FE;
         uwrpsTo=unwrappedCurrID;
@@ -142,7 +149,7 @@ public class OPunary extends OPfunction {
     //          resType.isAssignableFrom(currClass))) {
       // widening reference conversion does not require any code
       if ((implCode=una[code][unwrappedCurrID])==0xFF) {
-        Debug.println("code="+code);
+        //Debug.println("code="+code);
         // can't convert at all
         Object[] paramsExc={currClass,resType};
         throw new CompilationException(-1,21,paramsExc);
@@ -182,11 +189,11 @@ public class OPunary extends OPfunction {
   protected void compile_pre(ClassFile cf) {
     if (code==2) cf.code(0xFB); // equivalent to cf.labels_block();
     if (code==14) {
-      cf.code(0x00591CFDBBL); // STR => TSB
+      cf.code(0x0001FE591DFDBBL); // ANY => TSB
       //                      | new
       //                          <CP: java.lang.StringBuffer>
       //                      | dup
-      cf.typesStk.pushID(10); // pushes ref to TSB
+      //                      | invokespecial StringBuffer()
       cf.typesStk.pushID(10); // pushes ref to TSB
     };
   };
@@ -198,7 +205,7 @@ public class OPunary extends OPfunction {
       cf.typesStk.pop();
       cf.typesStk.pushID(uwrpsTo);
     };
-            
+
     cf.code(implCode);
 
     if (code==12) // code CP index for conversion to reference
@@ -208,8 +215,6 @@ public class OPunary extends OPfunction {
     switch(code) {
     case 2:  // logical inversion does not change stack
       break;
-    case 14: // conversion to TSB throws one extra word from stack
-      cf.typesStk.pop();
     case 3:
     case 13:
       cf.typesStk.pop(); // return and (void) throw one word, add nothing
@@ -262,8 +267,8 @@ public class OPunary extends OPfunction {
       opl.resID=resID;
     } else {
       // conversion operations
-      if (code==14) { // STR->TSB
-        opl.what=new StringBuffer((String) opl.what);
+      if (code==14) { // ANY->TSB
+        opl.what=new StringBuffer(String.valueOf(opl.what));
       } else if (code==15) { // TSB->STR
         opl.what=opl.what.toString();
       } else {
