@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
- * $Id: TableKeeper.java,v 1.2 2000/09/10 15:59:34 metlov Exp $
+ * $Id: TableKeeper.java,v 1.4 2001/01/22 15:58:20 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -111,7 +111,8 @@ public class TableKeeper {
           "java.lang.Integer",                          // 24 0x18
           "java.lang.Long",                             // 25 0x19
           "java.lang.Float",                            // 26 0x1A
-          "java.lang.Double"                            // 27 0x1B
+          "java.lang.Double",                           // 27 0x1B
+          "gnu.jel.reflect.String"                      // 28 0x1C
         };
         tables.put("specialTypes",specialTypesStr);
 
@@ -134,7 +135,7 @@ public class TableKeeper {
           0,1,2,3,4,5,6,7,8,9,
           8,8,
           8,8,8,8,8,8,8,8,
-          8,8,8,8,8,8,8,8
+          8,8,8,8,8,8,8,8,8
         };
         tables.put("baseType",baseType);
         
@@ -142,7 +143,7 @@ public class TableKeeper {
           0,1,2,3,4,5,6,7,8,9,
           10,11,
           0,1,2,3,4,5,6,7,
-          0,1,2,3,4,5,6,7
+          0,1,2,3,4,5,6,7,11
         };
         tables.put("unwrapType",unwrapType);
         
@@ -178,8 +179,8 @@ public class TableKeeper {
 
         // Tables from gnu.jel.ClassFile        
         String[] specialClassesAddStr={
-          "java.lang.StringBuffer",          // 28 0x1C
-          "java.lang.Object",                // 29 0x1D
+          "java.lang.StringBuffer",          // 29 0x1D // former 0x1C
+          "java.lang.Object",                // 30 0x1E // former 0x1D
         };
         tables.put("specialClassesAdd",specialClassesAddStr);
 
@@ -208,17 +209,17 @@ public class TableKeeper {
   
         // in no particular order
         char[][] specialMds={
-          {29,0},              // Object.toString()                    |  0
-          {28+100,0,11},       // StringBuffer(String)                 |  1
-          {28,1,0},            // StringBuffer.append(boolean)         |  2
-          {28,1,2},            // StringBuffer.append(char)            |  3
-          {28,1,4},            // StringBuffer.append(int)             |  4
-          {28,1,5},            // StringBuffer.append(long)            |  5
-          {28,1,6},            // StringBuffer.append(float)           |  6
-          {28,1,7},            // StringBuffer.append(double)          |  7
-          {28,1,11},           // StringBuffer.append(String)          |  8
-          {28,1,29},           // StringBuffer.append(Object)          |  9
-          {28,0},              // StringBuffer.toString()              | 10
+          {30,0},              // Object.toString()                    |  0
+          {29+100,0},          // StringBuffer()                       |  1
+          {29,1,0},            // StringBuffer.append(boolean)         |  2
+          {29,1,2},            // StringBuffer.append(char)            |  3
+          {29,1,4},            // StringBuffer.append(int)             |  4
+          {29,1,5},            // StringBuffer.append(long)            |  5
+          {29,1,6},            // StringBuffer.append(float)           |  6
+          {29,1,7},            // StringBuffer.append(double)          |  7
+          {29,1,11},           // StringBuffer.append(String)          |  8
+          {29,1,30},           // StringBuffer.append(Object)          |  9
+          {29,0},              // StringBuffer.toString()              | 10
           {12,2},              // gnu.jel.reflect.Boolean.getValue()   | 11
           {13,2},              // gnu.jel.reflect.Byte.getValue()      | 12
           {14,2},              // gnu.jel.reflect.Character.getValue() | 13
@@ -234,22 +235,24 @@ public class TableKeeper {
           {24,7},              // java.lang.Integer.intValue()         | 23
           {25,8},              // java.lang.Long.longValue()           | 24
           {26,9},              // java.lang.Float.floatValue()         | 25
-          {27,10}              // java.lang.Double.doubleValue()       | 26
+          {27,10},             // java.lang.Double.doubleValue()       | 26
+          {11,11,30},          // String.valueOf(Object)               | 27 // unwraps String-like
         };
         tables.put("specialMds",specialMds);
 
         String[] specialMdsN = {
-          "toString",          //                               |  0
-          "append",            //                               |  1
-          "getValue",          //                               |  2
-          "booleanValue",      //                               |  3
-          "byteValue",         //                               |  4
-          "charValue",         //                               |  5
-          "shortValue",        //                               |  6
-          "intValue",          //                               |  7
-          "longValue",         //                               |  8
-          "floatValue",        //                               |  9
-          "doubleValue"        //                               | 10
+          "toString",          //                               |  0 0x00
+          "append",            //                               |  1 0x01
+          "getValue",          //                               |  2 0x02
+          "booleanValue",      //                               |  3 0x03
+          "byteValue",         //                               |  4 0x04
+          "charValue",         //                               |  5 0x05
+          "shortValue",        //                               |  6 0x06
+          "intValue",          //                               |  7 0x07
+          "longValue",         //                               |  8 0x08
+          "floatValue",        //                               |  9 0x09
+          "doubleValue",       //                               | 10 0x0A
+          "valueOf"            //                               | 11 0x0B
         };
         tables.put("specialMdsN",specialMdsN);
 
@@ -270,14 +273,14 @@ public class TableKeeper {
           {  0xFF,  0x87,  0x87,  0x87,  0x87,    0x8A,  0x8D,     0,  0XFF,0xFF,    0xFF,  0xFF},// D  |11
           {  0xFF,  0xFF,  0xFF,  0xFF,  0xFF,    0xFF,  0xFF,  0xFF,  0xc0,0xFF,    0xFF,  0xc0},// L  |12
           {0x57FA,  0x57,  0x57,  0x57,  0x57,    0x58,  0x57,  0x58,  0x57,   0,    0x57,  0x57},//VOID|13
-          {  0xFF,  0xFF,  0xFF,  0xFF,  0xFF,    0xFF,  0xFF,  0xFF,  0xFF,0xFF,       0,0x01FE},// TSB|14
-          {  0xFF,  0xFF,  0xFF,  0xFF,  0xFF,    0xFF,  0xFF,  0xFF,0x00FE,0xFF,  0x0AFE,     0},// STR|15
+          {  0xFF,  0xFF,  0xFF,  0xFF,  0xFF,    0xFF,  0xFF,  0xFF,0x09FE,0xFF,       0,0x08FE},// TSB|14
+          {  0xFF,  0xFF,  0xFF,  0xFF,  0xFF,    0xFF,  0xFF,  0xFF,0x1BFE,0xFF,  0x0AFE,     0},// STR|15
         };
         tables.put("una",una);
 
         String[] opSymbols={"--","~","!","<RET>","(Z)","(B)",
                             "(C)","(S)","(I)","(J)",
-                            "(F)","(D)","(L)","(POP)","->TSB","TSB->"};
+                            "(F)","(D)","(L)","(POP)","->TSB","->STR"};
         tables.put("opSymbols",opSymbols);
         
         String[] opNames={"negation","bitwise inversion",
