@@ -21,7 +21,7 @@ import gnu.jel.debug.Debug;
  */
 public class LocalField implements Member {
   protected int modifiers;
-  private String name;
+  private java.lang.String name;
   private Class type;
   private int typeID;
   private Object constValue;
@@ -37,7 +37,7 @@ public class LocalField implements Member {
    * @param constValue is the value of this field if it is static final,
    *                   <TT>null</TT> otherwise.
    */
-  public LocalField(int modifiers, Class type, String name, Object constValue){
+  public LocalField(int modifiers, Class type, java.lang.String name, Object constValue){
 	this.type=type;
 	this.typeID=gnu.jel.TypesStack.typeID(type);
 	this.name=name;
@@ -53,7 +53,7 @@ public class LocalField implements Member {
   	return null; // means local field
   };
 
-  public String getName() {
+  public java.lang.String getName() {
 	return name;
   };
 
