@@ -34,7 +34,7 @@ public class LocalMethod extends LocalField {
    * @param paramTypes array of types of formal parameters.
    * @param exceptions checked exceptions thrown
    */
-  public LocalMethod(int modifiers, Class type, String name, 
+  public LocalMethod(int modifiers, Class type, java.lang.String name, 
                      Class[] paramTypes,Class[] exceptions) {
 	super(modifiers,type,name,null);
     
