@@ -1,5 +1,5 @@
 /*-*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * $Id: VariableProvider.java,v 1.9 2000/11/12 14:59:34 metlov Exp $
+ * $Id: VariableProvider.java,v 1.11 2001/01/22 15:58:20 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -27,6 +27,10 @@ public class VariableProvider implements gnu.jel.DVResolver {
     return (gnu.jel.reflect.Double) properties.get(name);
   };
 
+  public DoubleObject getTSDoubleProperty(String name) {
+    return (DoubleObject) properties.get(name);
+  };
+
   public gnu.jel.reflect.Boolean getBooleanProperty(String name) {
     return (gnu.jel.reflect.Boolean) properties.get(name);
   };
@@ -43,6 +47,7 @@ public class VariableProvider implements gnu.jel.DVResolver {
     Object val=properties.get(name);
     if (val==null) return null;
     if (val instanceof String) return "String";
+    if (val.getClass()==DoubleObject.class) return "TSDouble";
     if (val instanceof gnu.jel.reflect.Double) return "Double";
     if (val instanceof gnu.jel.reflect.Boolean) return "Boolean";
     return null;
@@ -136,6 +141,7 @@ public class VariableProvider implements gnu.jel.DVResolver {
   public long valLong=1;
   public float valFloat=(float)1.0;
   public double valDouble=1.0;
+  public StringObject valString=new StringObject("strObj");
 
   public java.lang.Boolean valBooleanObj=new java.lang.Boolean(true);
   public java.lang.Byte valByteObj=new java.lang.Byte((byte)1);
@@ -188,6 +194,17 @@ public class VariableProvider implements gnu.jel.DVResolver {
     return new DoubleObject(d);
   };
 
+  // next two methods test overloading of unwrappable types
+  public static int methodOnInt(int i) {
+    return i;
+  };
+  public static int methodOnInt(gnu.jel.reflect.Integer iobj) {
+    return iobj.getValue()+1;
+  };
+
+  public static String append_ttt(String str) {
+    return str+"_ttt";
+  };
 
 };
 
